@@ -1,7 +1,7 @@
 /*
  * Wrapper for decompressing LZIP-compressed kernel, initramfs, and initrd
  *
- * Copyright (C) 2016-2024 Antonio Diaz Diaz.
+ * Copyright (C) 2016-2025 Antonio Diaz Diaz.
  *
  * Licensed under GPLv2 or later, see file LICENSE in this source tree.
  */
@@ -62,6 +62,9 @@ STATIC int INIT __lunzip(unsigned char *inbuf, long in_len,
 	case LZIP_BAD_CRC:
 		error("CRC mismatch in LZIP-compressed data.");
 		break;
+	case LZIP_EMPTY_MEMBER:
+		error("Empty member in LZIP multimember data.");
+		break;
 	default: error("Bug in the LZIP decompressor.");
 	}
 	return retval;
