@@ -4,7 +4,7 @@
 /*
  * LZIP decompressor
  *
- * Copyright (C) 2016-2024 Antonio Diaz Diaz.
+ * Copyright (C) 2016-2025 Antonio Diaz Diaz.
  */
 
 /* Return values (< 0 = Error) */
@@ -20,7 +20,8 @@ enum {
 	LZIP_WRITE_ERROR   = -9,
 	LZIP_BAD_DATA      = -10,
 	LZIP_DATA_EOF      = -11,
-	LZIP_BAD_CRC       = -12
+	LZIP_BAD_CRC       = -12,
+	LZIP_EMPTY_MEMBER  = -13
 };
 
 int lzip_decompress(unsigned char *inbuf, long in_len,
