@@ -1,7 +1,7 @@
 /*
  * LZIP decompressor
  *
- * Copyright (C) 2016-2024 Antonio Diaz Diaz.
+ * Copyright (C) 2016-2025 Antonio Diaz Diaz.
  *
  * Licensed under GPLv2 or later, see file LICENSE in this source tree.
  */
@@ -40,7 +40,7 @@ static inline State St_set_rep(const State st)
 	return (st < 7) ? 8 : 11;
 }
 
-static inline State St_set_short_rep(const State st)
+static inline State St_set_shortrep(const State st)
 {
 	return (st < 7) ? 9 : 11;
 }
@@ -359,14 +359,17 @@ static inline uint8_t Rd_get_byte(struct Range_decoder * const rdec)
 	return rdec->buffer[rdec->pos++];
 }
 
-static inline void Rd_load(struct Range_decoder * const rdec)
+static inline bool Rd_load(struct Range_decoder * const rdec)
 {
 	int i;
 
 	rdec->code = 0;
 	rdec->range = 0xFFFFFFFFU;
-	Rd_get_byte(rdec);	/* discard first byte of the LZMA stream */
+	/* check first byte of the LZMA stream */
+	if (Rd_get_byte(rdec) != 0)
+		return false;
 	for (i = 0; i < 4; ++i) rdec->code = (rdec->code << 8) | Rd_get_byte(rdec);
+	return true;
 }
 
 static inline void Rd_normalize(struct Range_decoder * const rdec)
@@ -693,7 +696,8 @@ static int LZd_decode_member(struct LZ_decoder * const d)
 	unsigned rep3 = 0;
 	State state = 0;
 
-	Rd_load(rdec);
+	if (!Rd_load(rdec))
+		return LZIP_BAD_DATA;
 	while (!Rd_finished(rdec)) {
 		int len;
 		const int pos_state = LZd_data_position(d) & pos_state_mask;
@@ -715,7 +719,7 @@ static int LZd_decode_member(struct LZ_decoder * const d)
 		if (Rd_decode_bit(rdec, &d->bm_rep[state]) != 0) {
 			if (Rd_decode_bit(rdec, &d->bm_rep0[state]) == 0) {
 				if (Rd_decode_bit(rdec, &d->bm_len[state][pos_state]) == 0) {
-					state = St_set_short_rep(state);
+					state = St_set_shortrep(state);
 					LZd_put_byte(d, LZd_peek(d, rep0));
 					continue;
 				}
@@ -739,23 +743,21 @@ static int LZd_decode_member(struct LZ_decoder * const d)
 			state = St_set_rep(state);
 			len = Rd_decode_len(rdec, &d->rep_len_model, pos_state);
 		} else {			/* match */
-			unsigned distance;
-
+			rep3 = rep2; rep2 = rep1; rep1 = rep0;
 			len = Rd_decode_len(rdec, &d->match_len_model, pos_state);
-			distance = Rd_decode_tree6(rdec, d->bm_dis_slot[get_len_state(len)]);
-			if (distance >= start_dis_model) {
-				const unsigned dis_slot = distance;
+			rep0 = Rd_decode_tree6(rdec, d->bm_dis_slot[get_len_state(len)]);
+			if (rep0 >= start_dis_model) {
+				const unsigned dis_slot = rep0;
 				const int direct_bits = (dis_slot >> 1) - 1;
 
-				distance = (2 | (dis_slot & 1)) << direct_bits;
+				rep0 = (2 | (dis_slot & 1)) << direct_bits;
 				if (dis_slot < end_dis_model)
-					distance += Rd_decode_tree_reversed(rdec,
-						d->bm_dis + (distance - dis_slot), direct_bits);
+					rep0 += Rd_decode_tree_reversed(rdec,
+						d->bm_dis + (rep0 - dis_slot), direct_bits);
 				else {
-					distance +=
-					  Rd_decode(rdec, direct_bits - dis_align_bits) << dis_align_bits;
-					distance += Rd_decode_tree_reversed4(rdec, d->bm_align);
-					if (distance == 0xFFFFFFFFU) {	/* marker found */
+					rep0 += Rd_decode(rdec, direct_bits - dis_align_bits) << dis_align_bits;
+					rep0 += Rd_decode_tree_reversed4(rdec, d->bm_align);
+					if (rep0 == 0xFFFFFFFFU) {	/* marker found */
 						Rd_normalize(rdec);
 						LZd_flush_data(d);
 						if (d->write_error)
@@ -770,7 +772,6 @@ static int LZd_decode_member(struct LZ_decoder * const d)
 					}
 				}
 			}
-			rep3 = rep2; rep2 = rep1; rep1 = rep0; rep0 = distance;
 			state = St_set_match(state);
 			if (rep0 >= d->dictionary_size ||
 			   (rep0 >= d->pos && !d->pos_wrapped)) {
@@ -796,6 +797,7 @@ int lzip_decompress(unsigned char *inbuf, long in_len,
 	struct LZ_decoder *decoder = 0;
 	int retval = 0;
 	bool first_member;
+	bool empty = false, multi = false;
 
 	if (in_posp)
 		*in_posp = 0;
@@ -849,7 +851,9 @@ int lzip_decompress(unsigned char *inbuf, long in_len,
 		retval = LZd_decode_member(decoder);
 		if (in_posp)
 			*in_posp += Rd_member_position(&rdec);
+		multi = !first_member;
 		data_pos = LZd_data_position(decoder);
+		if (data_pos == 0) empty = true;
 		if (outptr)
 			outptr += data_pos;
 		if (out_posp)
@@ -863,6 +867,8 @@ int lzip_decompress(unsigned char *inbuf, long in_len,
 	if (decoder)
 		free(decoder);
 	Rd_free(&rdec);
+	if (empty && multi && retval == 0)
+		retval = LZIP_EMPTY_MEMBER;
 	return retval;
 }
 
