@@ -1,6 +1,6 @@
 #! /bin/sh
 # check script for Xlunzip - Test tool for the lzip_decompress linux module
-# Copyright (C) 2016-2024 Antonio Diaz Diaz.
+# Copyright (C) 2016-2025 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
 # to copy, distribute, and modify it.
@@ -28,11 +28,11 @@ if [ -d tmp ] ; then rm -rf tmp ; fi
 mkdir tmp
 cd "${objdir}"/tmp || framework_failure
 
-cat "${testdir}"/test.txt > in || framework_failure
+cp "${testdir}"/test.txt in || framework_failure
 in_lz="${testdir}"/test.txt.lz
-in_em="${testdir}"/test_em.txt.lz
+em_lz="${testdir}"/em.lz
 fox_lz="${testdir}"/fox.lz
-zero_lz="${testdir}"/zero.lz
+fnz_lz="${testdir}"/fox_nz.lz
 fail=0
 test_failed() { fail=1 ; printf " $1" ; [ -z "$2" ] || printf "($2)" ; }
 
@@ -80,29 +80,24 @@ printf "LZIP\001+.............................." | "${LZIP}" -t 2> /dev/null
 
 printf "\ntesting decompression..."
 
-for i in "${in_lz}" "${in_em}" ; do
-	"${LZIP}" -t "$i" || test_failed $LINENO "$i"
-	"${LZIP}" -d "$i" -o out || test_failed $LINENO "$i"
-	cmp in out || test_failed $LINENO "$i"
-	"${LZIP}" -cd "$i" > out || test_failed $LINENO "$i"
-	cmp in out || test_failed $LINENO "$i"
-	"${LZIP}" -d "$i" -o - > out || test_failed $LINENO "$i"
-	cmp in out || test_failed $LINENO "$i"
-	"${LZIP}" -d < "$i" > out || test_failed $LINENO "$i"
-	cmp in out || test_failed $LINENO "$i"
-	rm -f out || framework_failure
-done
+"${LZIP}" -t "${in_lz}" || test_failed $LINENO
+"${LZIP}" -d "${in_lz}" -o out || test_failed $LINENO
+cmp in out || test_failed $LINENO
+"${LZIP}" -cd "${in_lz}" > out || test_failed $LINENO
+cmp in out || test_failed $LINENO
+"${LZIP}" -d "${in_lz}" -o - > out || test_failed $LINENO
+cmp in out || test_failed $LINENO
+"${LZIP}" -d < "${in_lz}" > out || test_failed $LINENO
+cmp in out || test_failed $LINENO
+rm -f out || framework_failure
 
-lines=`"${LZIP}" -tvv "${in_em}" 2>&1 | wc -l` || test_failed $LINENO
-[ "${lines}" -eq 1 ] || test_failed $LINENO "${lines}"
-
-cat "${in_lz}" > out.lz || framework_failure
+cp "${in_lz}" out.lz || framework_failure
 "${LZIP}" -dk out.lz || test_failed $LINENO
 cmp in out || test_failed $LINENO
 rm -f out || framework_failure
 "${LZIP}" -cd "${fox_lz}" > fox || test_failed $LINENO
-cat fox > copy || framework_failure
-cat "${in_lz}" > copy.lz || framework_failure
+cp fox copy || framework_failure
+cp "${in_lz}" copy.lz || framework_failure
 "${LZIP}" -d copy.lz out.lz 2> /dev/null	# skip copy, decompress out
 [ $? = 1 ] || test_failed $LINENO
 [ ! -e out.lz ] || test_failed $LINENO
@@ -116,7 +111,6 @@ rm -f copy out || framework_failure
 printf "to be overwritten" > out || framework_failure
 "${LZIP}" -df -o out < "${in_lz}" || test_failed $LINENO
 cmp in out || test_failed $LINENO
-rm -f out || framework_failure
 "${LZIP}" -d -o ./- "${in_lz}" || test_failed $LINENO
 cmp in ./- || test_failed $LINENO
 rm -f ./- || framework_failure
@@ -124,12 +118,12 @@ rm -f ./- || framework_failure
 cmp in ./- || test_failed $LINENO
 rm -f ./- || framework_failure
 
-cat "${in_lz}" > anyothername || framework_failure
+cp "${in_lz}" anyothername || framework_failure
 "${LZIP}" -dv - anyothername - < "${in_lz}" > out 2> /dev/null ||
 	test_failed $LINENO
 cmp in out || test_failed $LINENO
 cmp in anyothername.out || test_failed $LINENO
-rm -f out anyothername.out || framework_failure
+rm -f anyothername.out || framework_failure
 
 "${LZIP}" -tq in "${in_lz}"
 [ $? = 2 ] || test_failed $LINENO
@@ -142,7 +136,7 @@ cat out in | cmp in - || test_failed $LINENO		# out must be empty
 [ $? = 1 ] || test_failed $LINENO
 cmp in out || test_failed $LINENO
 rm -f out || framework_failure
-cat "${in_lz}" > out.lz || framework_failure
+cp "${in_lz}" out.lz || framework_failure
 "${LZIP}" -dq in out.lz
 [ $? = 2 ] || test_failed $LINENO
 [ -e out.lz ] || test_failed $LINENO
@@ -166,19 +160,73 @@ cmp in2 out2 || test_failed $LINENO
 rm -f out2 || framework_failure
 
 cat "${in_lz}" "${in_lz}" > out2.lz || framework_failure
+lines=`"${LZIP}" -tvv out2.lz 2>&1 | wc -l` || test_failed $LINENO
+[ "${lines}" -eq 1 ] || test_failed $LINENO "${lines}"
+
 printf "\ngarbage" >> out2.lz || framework_failure
 "${LZIP}" -tvvvv out2.lz 2> /dev/null || test_failed $LINENO
 printf "to be overwritten" > out2 || framework_failure
 "${LZIP}" -df out2.lz || test_failed $LINENO
 cmp in2 out2 || test_failed $LINENO
 
+touch empty || framework_failure
+cp "${em_lz}" em.lz || framework_failure
+"${LZIP}" -dk em.lz || test_failed $LINENO
+cmp empty em || test_failed $LINENO
+
 printf "\ntesting bad input..."
 
+cat em.lz em.lz | "${LZIP}" -tq
+[ $? = 2 ] || test_failed $LINENO
+cat em.lz em.lz | "${LZIP}" -dq > em
+[ $? = 2 ] || test_failed $LINENO
+cmp empty em || test_failed $LINENO
+cat em.lz "${in_lz}" | "${LZIP}" -tq
+[ $? = 2 ] || test_failed $LINENO
+cat em.lz "${in_lz}" | "${LZIP}" -dq > out
+[ $? = 2 ] || test_failed $LINENO
+cmp in out || test_failed $LINENO
+cat "${in_lz}" em.lz | "${LZIP}" -tq
+[ $? = 2 ] || test_failed $LINENO
+cat "${in_lz}" em.lz | "${LZIP}" -dq > out
+[ $? = 2 ] || test_failed $LINENO
+cmp in out || test_failed $LINENO
+cat em.lz em.lz > ee.lz || framework_failure
+"${LZIP}" -tq < ee.lz
+[ $? = 2 ] || test_failed $LINENO
+"${LZIP}" -dq < ee.lz > em
+[ $? = 2 ] || test_failed $LINENO
+cmp empty em || test_failed $LINENO
+"${LZIP}" -tq ee.lz
+[ $? = 2 ] || test_failed $LINENO
+"${LZIP}" -dq ee.lz
+[ $? = 2 ] || test_failed $LINENO
+[ ! -e ee ] || test_failed $LINENO
+"${LZIP}" -cdq ee.lz > em
+[ $? = 2 ] || test_failed $LINENO
+cmp empty em || test_failed $LINENO
+rm -f em || framework_failure
+cat "${in_lz}" em.lz "${in_lz}" > inein.lz || framework_failure
+"${LZIP}" -tq < inein.lz
+[ $? = 2 ] || test_failed $LINENO
+"${LZIP}" -dq < inein.lz > out2
+[ $? = 2 ] || test_failed $LINENO
+cmp in2 out2 || test_failed $LINENO
+"${LZIP}" -tq inein.lz
+[ $? = 2 ] || test_failed $LINENO
+"${LZIP}" -dq inein.lz
+[ $? = 2 ] || test_failed $LINENO
+[ ! -e inein ] || test_failed $LINENO
+"${LZIP}" -cdq inein.lz > out2
+[ $? = 2 ] || test_failed $LINENO
+cmp in2 out2 || test_failed $LINENO
+rm -f out2 inein.lz em.lz || framework_failure
+
 headers='LZIp LZiP LZip LzIP LzIp LziP lZIP lZIp lZiP lzIP'
-body='\001\014\000\203\377\373\377\377\300\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000$\000\000\000\000\000\000\000'
-cat "${in_lz}" > int.lz || framework_failure
+body='\001\014\000\000\101\376\367\377\377\340\000\200\000\215\357\002\322\001\000\000\000\000\000\000\000\045\000\000\000\000\000\000\000'
+cp "${in_lz}" int.lz || framework_failure
 printf "LZIP${body}" >> int.lz || framework_failure
-if "${LZIP}" -tq int.lz ; then
+if "${LZIP}" -t int.lz ; then
 	for header in ${headers} ; do
 		printf "${header}${body}" > int.lz || framework_failure
 		"${LZIP}" -tq int.lz			# first member
@@ -187,7 +235,7 @@ if "${LZIP}" -tq int.lz ; then
 		[ $? = 2 ] || test_failed $LINENO ${header}
 		"${LZIP}" -cdq int.lz > /dev/null
 		[ $? = 2 ] || test_failed $LINENO ${header}
-		cat "${in_lz}" > int.lz || framework_failure
+		cp "${in_lz}" int.lz || framework_failure
 		printf "${header}${body}" >> int.lz || framework_failure
 		"${LZIP}" -tq int.lz			# trailing data
 		[ $? = 2 ] || test_failed $LINENO ${header}
@@ -197,10 +245,13 @@ if "${LZIP}" -tq int.lz ; then
 		[ $? = 2 ] || test_failed $LINENO ${header}
 	done
 else
-	printf "\nwarning: skipping header test: 'printf' does not work on your system."
+	printf "warning: skipping header test: 'printf' does not work on your system."
 fi
 rm -f int.lz || framework_failure
 
+"${LZIP}" -tq "${fnz_lz}"
+[ $? = 2 ] || test_failed $LINENO
+
 for i in fox_v2.lz fox_s11.lz fox_de20.lz \
          fox_bcrc.lz fox_crc0.lz fox_das46.lz fox_mes81.lz ; do
 	"${LZIP}" -tq "${testdir}"/$i
@@ -212,13 +263,13 @@ for i in fox_bcrc.lz fox_crc0.lz fox_das46.lz fox_mes81.lz ; do
 	[ $? = 2 ] || test_failed $LINENO $i
 	cmp fox out || test_failed $LINENO $i
 done
-rm -f fox out || framework_failure
+rm -f fox || framework_failure
 
 cat "${in_lz}" "${in_lz}" > in2.lz || framework_failure
 cat "${in_lz}" "${in_lz}" "${in_lz}" > in3.lz || framework_failure
-if dd if=in3.lz of=trunc.lz bs=14752 count=1 2> /dev/null &&
-   [ -e trunc.lz ] && cmp in2.lz trunc.lz > /dev/null 2>&1 ; then
-	for i in 6 20 14734 14753 14754 14755 14756 14757 14758 ; do
+if dd if=in3.lz of=trunc.lz bs=14682 count=1 2> /dev/null &&
+   [ -e trunc.lz ] && cmp in2.lz trunc.lz ; then
+	for i in 6 20 14664 14683 14684 14685 14686 14687 14688 ; do
 		dd if=in3.lz of=trunc.lz bs=$i count=1 2> /dev/null
 		"${LZIP}" -tq trunc.lz
 		[ $? = 2 ] || test_failed $LINENO $i
@@ -230,15 +281,17 @@ if dd if=in3.lz of=trunc.lz bs=14752 count=1 2> /dev/null &&
 		[ $? = 2 ] || test_failed $LINENO $i
 	done
 else
-	printf "\nwarning: skipping truncation test: 'dd' does not work on your system."
+	printf "warning: skipping truncation test: 'dd' does not work on your system."
 fi
 rm -f trunc.lz || framework_failure
 
-cat "${in_lz}" > ingin.lz || framework_failure
+cp "${in_lz}" ingin.lz || framework_failure
 printf "g" >> ingin.lz || framework_failure
 cat "${in_lz}" >> ingin.lz || framework_failure
 "${LZIP}" -t ingin.lz || test_failed $LINENO
 "${LZIP}" -t < ingin.lz || test_failed $LINENO
+"${LZIP}" -dk ingin.lz || test_failed $LINENO
+cmp in ingin || test_failed $LINENO
 "${LZIP}" -cd ingin.lz > out || test_failed $LINENO
 cmp in out || test_failed $LINENO
 "${LZIP}" -d < ingin.lz > out || test_failed $LINENO
@@ -274,7 +327,7 @@ for i in =18KiB =65536 =262144 ; do
 	cmp in out || test_failed $LINENO $i
 done
 
-for i in =36388 =65536 =262144 ; do
+for i in =36301 =65536 =262144 ; do
 	"${LZIP}" -t --outsize$i --noflush "${in_lz}" ||
 		test_failed $LINENO $i
 	"${LZIP}" -cd --outsize$i --noflush "${in_lz}" > out ||
@@ -282,7 +335,7 @@ for i in =36388 =65536 =262144 ; do
 	cmp in out || test_failed $LINENO $i
 done
 
-for i in =36387 ; do
+for i in =36300 ; do
 	"${LZIP}" -tq --outsize$i --noflush "${in_lz}"
 	[ $? = 1 ] || test_failed $LINENO $i
 	"${LZIP}" -cdq --outsize$i --noflush "${in_lz}" > out
@@ -352,18 +405,21 @@ for i in in2 in3 ; do
 done
 "${LZIP}" -tq --in-place ingin.lz
 [ $? = 2 ] || test_failed $LINENO
-rm -f out out2 ingin.lz in2 in2.lz in3 in3.lz || framework_failure
+rm -f out2 ingin.lz in2 in2.lz in3 in3.lz || framework_failure
 
-cat "${in_lz}" > inz.lz || framework_failure
-counter=0
-while [ ${counter} -lt 20 ] ; do
-	cat "${zero_lz}" >> inz.lz || framework_failure
-	"${LZIP}" -t --in-place inz.lz || test_failed $LINENO
-	"${LZIP}" -cd --in-place inz.lz > out || test_failed $LINENO
-	cmp in out || test_failed $LINENO
-	counter=$((counter+1))
-done
-rm -f out inz.lz || framework_failure
+cat "${in_lz}" "${em_lz}" > ine.lz || framework_failure
+"${LZIP}" -tq --in-place ine.lz
+[ $? = 2 ] || test_failed $LINENO
+"${LZIP}" -cdq --in-place ine.lz > out
+[ $? = 2 ] || test_failed $LINENO
+cmp empty out || test_failed $LINENO
+cat "${em_lz}" "${in_lz}" > ine.lz || framework_failure
+"${LZIP}" -tq --in-place ine.lz
+[ $? = 2 ] || test_failed $LINENO
+"${LZIP}" -cdq --in-place ine.lz > out
+[ $? = 2 ] || test_failed $LINENO
+cmp empty out || test_failed $LINENO
+rm -f ine.lz empty || framework_failure
 
 # decompress with trailing data in place
 cat "${in_lz}" in in in in > int.lz || framework_failure
